jest.disableAutomock();

import React from 'react';
import ReactDOM from 'react-dom';
import TestUtils from 'react-addons-test-utils';
import expect from 'expect';

import data from '../data/user-data.json';
import XAxis from '../../src/axis/XAxis';
import common from '../../src/utils/CoreCommonProps';

describe('Axes, set x accessor', () => {

	//Common Vars
	const height = common.height;
	const margins = common.margins;
	const x = function(d) { return d.index; }

	it('Create xaxis, default orient is bottom, and with default height and margins', () => {

		const newGroup = TestUtils.renderIntoDocument(
			<XAxis x={x} />
		);

		const dom = ReactDOM.findDOMNode(newGroup);
		expect(dom.getAttribute('transform')).toEqual(`translate(0, ${height - margins.top - margins.bottom})`)
	})

	it('Create xaxis, orient in bottom', () => {

		const newGroup = TestUtils.renderIntoDocument(
			<XAxis x={x} xOrient={'bottom'} />
		);

		const dom = ReactDOM.findDOMNode(newGroup)
		expect(dom.getAttribute('transform')).toEqual(`translate(0, ${height - margins.top - margins.bottom})`)
	})

	it('Create xaxis, orient in top', () => {

		var newGroup = TestUtils.renderIntoDocument(
			<XAxis x={x} xOrient={'top'} />
		);

		var dom = ReactDOM.findDOMNode(newGroup)
		expect(dom.getAttribute('transform')).toEqual('translate(0, 0)')
	})

	it('Create xaxis, with custom styles', () => {

		var newGroup = TestUtils.renderIntoDocument(
			<XAxis x={x} showAxis={false} style={{ background: 'red' }} />
		);

		var dom = ReactDOM.findDOMNode(newGroup);
	})
})
